diff --git a/Lottery/MainPage.xaml.cs b/Lottery/MainPage.xaml.cs
index 5b492e3..ff8a90a 100644
--- a/Lottery/MainPage.xaml.cs
+++ b/Lottery/MainPage.xaml.cs
@@ -2,7 +2,7 @@
{
public partial class MainPage : ContentPage
{
- readonly List Generators = [new UKGenerator(), new EuroGenerator(), new SetForLifeGenerator(), new ThunderBallGenerator()];
+ readonly List Generators = [new UKLottoGenerator(), new EuroMillionsGenerator(), new SetForLifeGenerator(), new ThunderBallGenerator()];
IGenerator Generator;
const KindOfLotto DEFAULT_GENERATOR = KindOfLotto.Uk;
Dictionary SpecialIdentifiers = new() {
diff --git a/Lottery/Generator.cs b/Lottery/Generator.cs
index bbf0142..78a9c66 100644
--- a/Lottery/Generator.cs
+++ b/Lottery/Generator.cs
@@ -4,7 +4,7 @@
///
/// Abstract base class for generators
- /// It implements the IGenerator interface
+ /// All subclasses must implement the IGenerator interface
/// Provides some default implementation
///
class Generator : IGenerator
@@ -26,10 +26,10 @@
}
///
- /// Concrete UKGenerator class.
+ /// Concrete UKLottoGenerator class.
/// Generates six balls from 1 to 59
///
- class UKGenerator : Generator
+ class UKLottoGenerator : Generator
{
private readonly Limits Limits = new(6, 1, 59);
@@ -42,10 +42,10 @@
}
///
/// Concrete EuroGenerator class.
/// Generates five balls from 1 to 50 and two balls from 1 to 12
///
- class EuroGenerator : Generator
+ class EuroMillionsGenerator : Generator
{
private readonly Limits NormalLimits = new(5, 1, 50);
private readonly Limits SpecialLimits = new(2, 1, 12);
@@ -42,10 +42,10 @@
}
///
- /// Concrete EuroGenerator class.
+ /// Concrete EuroMillionsGenerator class.
/// Generates five balls from 1 to 50 and two balls from 1 to 12
///